# RoboCore

**RoboCore** — это графическое приложение на Python с использованием PyQt5, предназначенное для запуска и управления тремя отдельными программами:

1. **ControllerManager** — управление сервоприводами.
2. **SpiderBotController** — управление робопауком.
3. **SmartHomeController** — управление умным домом.

Приложение предоставляет удобный интерфейс для выбора и запуска одного из этих приложений.

## Основные функции

- **Запуск приложений:**
  - Пользователь может выбрать одно из трёх доступных приложений для запуска через интерфейс.

- **Подключение к COM-порту:**
  - Каждое из приложений может подключаться к доступным COM-портам для управления внешними устройствами (например, сервоприводами или умным домом).

- **Управление устройствами:**
  - **ControllerManager**: Управление углом поворота и скоростью движения для четырёх сервоприводов.
  - **SpiderBotController**: Управление движениями робопаука, включая его походку, шаги, и маневры.
  - **SmartHomeController**: Управление устройствами умного дома (освещение, температура, безопасность).

- **Сохранение и загрузка настроек:**
  - Возможность сохранять текущие настройки для каждого приложения и загружать их в дальнейшем.

- **Прошивка устройств:**
  - Загрузка прошивки на устройства через **arduino-cli** для **ControllerManager** и **SpiderBotController**.

- **Справка:**
  - Информация о каждом приложении и разработчике доступна в меню справки.

## Установка

1. Клонируйте репозиторий:

    ```bash
    git clone https://github.com/PlagueEvgeny/RoboCore.git
    cd RoboCore
    ```

2. Установите необходимые зависимости:

    ```bash
    pip install -r requirements.txt
    ```

3. Убедитесь, что у вас установлен **arduino-cli** для загрузки прошивки.

4. Запустите **RoboCore**:

    ```bash
    python RoboCore.py
    ```

## Использование

1. **Выбор приложения:** 
   - При запуске **RoboCore** отображает окно с тремя кнопками для запуска соответствующих приложений: **ControllerManager**, **SpiderBotController**, и **SmartHomeController**.

2. **Управление приложениями:**
   - После выбора одного из приложений, оно запускается в отдельном окне для дальнейшего взаимодействия.

3. **Справка:**
   - Через верхнее меню можно открыть справочную информацию о каждом из приложений, включая руководство пользователя и информацию о компании.

## Требования

- Python 3.7+
- PyQt5
- arduino-cli (для загрузки прошивок на устройства)

## Лицензия

Проект распространяется под лицензией MIT. Подробности можно найти в файле LICENSE.
